************************************************
* Stata source code:
*
* Henderson, H., L. Corral, E. Simning, and P. Winters. 
* "Land Accumulation Dynamics in Developing Country 
* Agriculture." 
*
* Last revised: 7/8/2014
* Comments: For code to be functional the directory 
* path must be changed and select user-written 
* packages must be installed (i.e. xtabond2 and outreg)
************************************************

* Set-up
clear all
set more off
*ssc install xtabond2
*ssc install outreg

* Open data 
cd /Users/hendersonhl/Documents/Articles/Land-Accumulation-Dynamics/Data/Paraguay
use Panel.dta
xtset numero time

* Generate region variable
gen region = 1 
replace region = 2 if colonization==1
replace region = 3 if minifundia==1
label var region "Region of HH"
order numero - d2007 region

* Generate labor and depend variables
drop labor
egen labor = rowtotal(madult fadult)
label var labor "Number of working age family members"
egen depend = rowtotal(mchild fchild msenior fsenior)
label var depend "Number non-working age family members"
order numero-hhsize labor depend 

* Generate education variable
* Note: Education questions were not asked in 1991. However, education is 
* reasonably time invariant so we can exploit information from other years to 
* fill in missing information. Inspection of the data suggests that this appears 
* to be appropriate. 
replace education = F.education if education==.
replace education = F2.education if education==.
replace education = F3.education if education==.

* Generate experience variable
gen experience = age - education - 6
label var experience "Years of experience"
order numero-education experience

* Generate growth variable
* Note: If a producer ceases to cultivate land between times t and t+1, then
* their growth rate should be -1. The average growth rate between times t and 
* t+1 will then be -1 divided by the number of years elapsed.  
sort numero time
gen lnop = ln(operated)
gen growth = (F.lnop - lnop)/(F.year - year)
replace growth = -1/(F.year - year) if F.operated==0 & operated!=0
replace growth = growth*100
label var growth "Percentage growth in operational landholdings"

* Descriptive statistics
by year, sort: sum operated titled labor depend experience education
sort numero year

* Land accumulation graphic
preserve 
by numero, sort: egen count = count(numero)
drop if count!=5
gen temp = .
replace temp=1 if operated<=5 & year==1991
replace temp=2 if operated>5 & operated<=10 & year==1991
replace temp=3 if operated>10 & operated<=20 & year==1991
replace temp=4 if operated>20 & year==1991
by numero, sort: egen cohort=min(temp)
drop temp
by cohort year, sort: egen msize = mean(operated)
twoway (line msize year if cohort==1) (line msize year if cohort==2) ///
(line msize year if cohort==3) (line msize year if cohort==4) ///
(scatter msize year), ///
legend(order(1 "< 5 ha" 2 "5-10 ha" 3 "10-20 ha" 4 "> 20 ha")) ///
ytitle(Land Operated) xtitle(Year) scheme(s2mono) legend(rows(1))
restore

* Attrition analysis
* Note: Here we test the null of no attrition bias via (1) the coefficient
* on land operated in the probit regressions and (2) the coefficient on the
* attrition dummy in the OLS regressions. We do this for both levels and 
* growth in land operated. See the following for more information:
*
* Becketti, S., W. Gould, L. Lillard, and F. Welch (1988). The Panel Study of 
* Income Dynamics after Fourteen Years: An Evaluation. Journal of Labor 
* Economics 6, 472-492.
*
* Fitzgerald, J., P. Gottschalk, and R. Moffitt (1998). An Analysis of Sample 
* Attrition in Panel Data: The Michigan Panel Study of Income Dynamics. The 
* Journal of Human Resources 33(2), 251-299.
by numero, sort: egen count = count(numero)
gen attrit = 0
replace attrit = 1 if count<5 

* Attrition regressions
probit attrit operated titled labor depend experience education ///
if year==1991, vce(cluster region)
probit attrit lnop titled labor depend experience education ///
if year==1991, vce(cluster region)
probit attrit growth titled labor depend experience education ///
if year==1991, vce(cluster region)
reg operated attrit titled labor depend experience education ///
if year==1991, vce(cluster region) 
reg lnop attrit titled labor depend experience education ///
if year==1991, vce(cluster region)
reg growth attrit titled labor depend experience education ///
if year==1991, vce(cluster region)

* Drop select variables
drop count attrit

* Generate logged operated variables
order lnop, last
label var lnop "Log of operated"
gen lnop_sq = lnop^2
label var lnop_sq "Log of operated squared"
gen lnop_cu = lnop^3
label var lnop_cu "Log of operated cubed"

* Generate logged titled variable and associated dummy
gen dtitled = 0
replace dtitled = 1 if titled<1
label var dtitled "Dummy for zero-valued titled"
gen stitled = titled
replace stitled = 1 if stitled<1
gen lntitled = ln(stitled)
label var lntitled "Log of titled"
gen lntitled_sq = lntitled^2
label var lntitled_sq "Log of titled squared"
drop stitled

* Generate logged labor variable and associated dummy
gen dlabor = 0
replace dlabor = 1 if labor<1
label var dlabor "Dummy for zero-valued labor"
gen slabor = labor
replace slabor = 1 if slabor<1
gen lnlabor = ln(slabor)
label var lnlabor "Log of labor"
gen lnlabor_sq = lnlabor^2
label var lnlabor_sq "Log of labor squared"
drop slabor

* Generate logged depend variable and associated dummy
gen ddepend = 0
replace ddepend = 1 if depend<1
label var ddepend "Dummy for zero-valued depend"
gen sdepend = depend
replace sdepend = 1 if sdepend<1
gen lndepend = ln(sdepend)
label var lndepend "Log of depend"
gen lndepend_sq = lndepend^2
label var lndepend_sq "Log of depend squared"
drop sdepend

* Generate logged experience variables
* Note: Never takes on zero value.
gen lnexp = ln(experience)
label var lnexp "Log of experience"
gen lnexp_sq = lnexp^2
label var lnexp_sq "Log of experience squared"

* Generate logged education variable and associated dummy
gen deduc = 0
replace deduc = 1 if education<1
label var deduc "Dummy for zero-valued education"
gen seduc = education
replace seduc = 1 if seduc<1
gen lneduc = ln(seduc)
label var lneduc "Log of education"
gen lneduc_sq = lneduc^2
label var lneduc_sq "Log of education squared"
drop seduc

* Generate interaction terms
gen interact12 = lnop*lntitled
label var interact12 "Log operated and log titled interaction"
gen interact13 = lnop*lnlabor
label var interact13 "Log operated and log labor interaction"
gen interact14 = lnop*lndepend
label var interact14 "Log operated and log depend interaction"
gen interact15 = lnop*lnexp
label var interact15 "Log operated and log experience interaction"
gen interact16 = lnop*lneduc
label var interact16 "Log operated and log education interaction"

gen interact23 = lntitled*lnlabor
label var interact23 "Log titled and log labor interaction"
gen interact24 = lntitled*lndepend
label var interact24 "Log titled and log depend interaction"
gen interact25 = lntitled*lnexp
label var interact25 "Log titled and log experience interaction"
gen interact26 = lntitled*lneduc
label var interact26 "Log titled and log education interaction"

gen interact34 = lnlabor*lndepend
label var interact34 "Log labor and log depend interaction"
gen interact35 = lnlabor*lnexp
label var interact35 "Log labor and log experience interaction"
gen interact36 = lnlabor*lneduc
label var interact36 "Log labor and log education interaction"

gen interact45 = lndepend*lnexp
label var interact45 "Log depend and log experience interaction"
gen interact46 = lndepend*lneduc
label var interact46 "Log depend and log education interaction"
gen interact56 = lnexp*lneduc
label var interact56 "Log experience and log education interaction"

* Generate variable means for hypothesis tests
sum operated
scalar mop = r(mean)
sum titled
scalar mtitled = r(mean)
sum labor
scalar mlabor = r(mean)
sum depend
scalar mdepend = r(mean)
sum experience
scalar mexp = r(mean)
sum education
scalar meduc = r(mean)

* Macros for RHS variables
global rhs lnop lntitled lnlabor lndepend lnexp lneduc lnop_sq interact1* ///
lntitled_sq interact2* lnlabor_sq interact3* lndepend_sq interact4* ///
lnexp_sq interact5* lneduc_sq d1991 d1994 d1999 dtitled dlabor ddepend ///
deduc
global ivs d1991 d1994 d1999
global gmms lnop lntitled lnlabor lndepend lnexp lneduc lnop_sq ///
interact1* lntitled_sq interact2* lnlabor_sq interact3* lndepend_sq ///
interact4* lnexp_sq interact5* lneduc_sq dtitled dlabor ddepend deduc

************************************************
***************** Full Model *******************
************************************************

* Naive OLS model
* Note: The estimates on the lagged dependent variable are biased upward and, 
* thus, provide an upper bound estimate.
reg growth lnop lntitled lnlabor lndepend lnexp lneduc ///
d1991 d1994 d1999 dtitled dlabor ddepend deduc

* Naive within groups estimator
* Note: The estimates on the lagged dependent variable are biased downward and, 
* thus, provide a lower bound estimate.
xtreg growth lnop lntitled lnlabor lndepend lnexp lneduc ///
d1991 d1994 d1999 dtitled dlabor ddepend deduc, fe

* Systems GMM estimator: Without quadratic or interaction terms
xtabond2 growth lnop lntitled lnlabor lndepend lnexp lneduc ///
d1991 d1994 d1999 dtitled dlabor ddepend deduc, ///
iv($ivs, eq(level)) gmm(lnop lntitled lnlabor lndepend lnexp ///
lneduc dtitled dlabor ddepend deduc) twostep robust orthog

* Calculate R-squared
predict pgrowth if e(sample)
corr growth pgrowth if e(sample)
di r(rho)^2
drop pgrowth

* Systems GMM estimator: Full model 
* Note: Only time dummies are treated as strictly exogenous.
xtabond2 growth $rhs, iv($ivs, eq(level)) gmm($gmms) twostep robust orthog

* Export regression
outreg using /Users/hendersonhl/Desktop/sysgmm, tex se bdec(2) nosubstat ///
replace starlevels(10 5 1) starloc(1)

* Calculate R-squared
predict pgrowth if e(sample)
corr growth pgrowth if e(sample)
di r(rho)^2
drop pgrowth

* Operated
nlcom _b[lnop] + 2*_b[lnop_sq]*ln(mop) + _b[interact12]*ln(mtitled) ///
 + _b[interact13]*ln(mlabor) + _b[interact14]*ln(mdepend) ///
 + _b[interact15]*ln(mexp) + _b[interact16]*ln(meduc)

* Titled
nlcom _b[lntitled] + 2*_b[lntitled_sq]*ln(mtitled) ///
+ _b[interact12]*ln(mop) + _b[interact23]*ln(mlabor) ///
+ _b[interact24]*ln(mdepend) + _b[interact25]*ln(mexp) ///
+ _b[interact26]*ln(meduc)

* Labor
nlcom _b[lnlabor] + 2*_b[lnlabor_sq]*ln(mlabor) ///
+ _b[interact13]*ln(mop) + _b[interact23]*ln(mtitled) ///
+ _b[interact34]*ln(mdepend) + _b[interact35]*ln(mexp) ///
+ _b[interact36]*ln(meduc)

* Depend
nlcom _b[lndepend] + 2*_b[lndepend_sq]*ln(mdepend) ///
+ _b[interact14]*ln(mop) + _b[interact24]*ln(mtitled) ///
+ _b[interact34]*ln(mlabor) + _b[interact45]*ln(mexp) ///
+ _b[interact46]*ln(meduc)

* Experience
nlcom _b[lnexp] + 2*_b[lnexp_sq]*ln(mexp) ///
+ _b[interact15]*ln(mop) + _b[interact25]*ln(mtitled) ///
+ _b[interact35]*ln(mlabor) + _b[interact45]*ln(mdepend) ///
+ _b[interact56]*ln(meduc)

* Education
nlcom _b[lneduc] + 2*_b[lneduc_sq]*ln(meduc) ///
+ _b[interact16]*ln(mop) + _b[interact26]*ln(mtitled) ///
+ _b[interact36]*ln(mlabor) + _b[interact46]*ln(mdepend) ///
+ _b[interact56]*ln(mexp)

************************************************
****************** Collapsed *******************
************************************************

* Systems GMM estimator: Collapsed model 
* Note: Only time dummies are treated as strictly exogenous.
xtabond2 growth $rhs, iv($ivs, eq(level)) gmm($gmms, collapse) ///
twostep robust orthog

* Export regression
outreg using /Users/hendersonhl/Desktop/sysgmm, tex se bdec(2) nosubstat ///
merge starlevels(10 5 1) starloc(1)

* Calculate R-squared
predict pgrowth if e(sample)
corr growth pgrowth if e(sample)
di r(rho)^2
drop pgrowth

* Operated
nlcom _b[lnop] + 2*_b[lnop_sq]*ln(mop) + _b[interact12]*ln(mtitled) ///
 + _b[interact13]*ln(mlabor) + _b[interact14]*ln(mdepend) ///
 + _b[interact15]*ln(mexp) + _b[interact16]*ln(meduc)

* Titled
nlcom _b[lntitled] + 2*_b[lntitled_sq]*ln(mtitled) ///
+ _b[interact12]*ln(mop) + _b[interact23]*ln(mlabor) ///
+ _b[interact24]*ln(mdepend) + _b[interact25]*ln(mexp) ///
+ _b[interact26]*ln(meduc)

* Labor
nlcom _b[lnlabor] + 2*_b[lnlabor_sq]*ln(mlabor) ///
+ _b[interact13]*ln(mop) + _b[interact23]*ln(mtitled) ///
+ _b[interact34]*ln(mdepend) + _b[interact35]*ln(mexp) ///
+ _b[interact36]*ln(meduc)

* Depend
nlcom _b[lndepend] + 2*_b[lndepend_sq]*ln(mdepend) ///
+ _b[interact14]*ln(mop) + _b[interact24]*ln(mtitled) ///
+ _b[interact34]*ln(mlabor) + _b[interact45]*ln(mexp) ///
+ _b[interact46]*ln(meduc)

* Experience
nlcom _b[lnexp] + 2*_b[lnexp_sq]*ln(mexp) ///
+ _b[interact15]*ln(mop) + _b[interact25]*ln(mtitled) ///
+ _b[interact35]*ln(mlabor) + _b[interact45]*ln(mdepend) ///
+ _b[interact56]*ln(meduc)

* Education
nlcom _b[lneduc] + 2*_b[lneduc_sq]*ln(meduc) ///
+ _b[interact16]*ln(mop) + _b[interact26]*ln(mtitled) ///
+ _b[interact36]*ln(mlabor) + _b[interact46]*ln(mdepend) ///
+ _b[interact56]*ln(mexp)

************************************************
********** Collapsed and Restricted ************
************************************************

* Systems GMM estimator: Collapsed and restricted model 
* Note: Only time dummies are treated as strictly exogenous.
xtabond2 growth $rhs, iv($ivs, eq(level)) gmm($gmms, collapse lag(1 2)) ///
twostep robust orthog

* Export regression
outreg using /Users/hendersonhl/Desktop/sysgmm, tex se bdec(2) nosubstat ///
merge starlevels(10 5 1) starloc(1)

* Calculate R-squared
predict pgrowth if e(sample)
corr growth pgrowth if e(sample)
di r(rho)^2
drop pgrowth

* Operated
nlcom _b[lnop] + 2*_b[lnop_sq]*ln(mop) + _b[interact12]*ln(mtitled) ///
 + _b[interact13]*ln(mlabor) + _b[interact14]*ln(mdepend) ///
 + _b[interact15]*ln(mexp) + _b[interact16]*ln(meduc)

* Titled
nlcom _b[lntitled] + 2*_b[lntitled_sq]*ln(mtitled) ///
+ _b[interact12]*ln(mop) + _b[interact23]*ln(mlabor) ///
+ _b[interact24]*ln(mdepend) + _b[interact25]*ln(mexp) ///
+ _b[interact26]*ln(meduc)

* Labor
nlcom _b[lnlabor] + 2*_b[lnlabor_sq]*ln(mlabor) ///
+ _b[interact13]*ln(mop) + _b[interact23]*ln(mtitled) ///
+ _b[interact34]*ln(mdepend) + _b[interact35]*ln(mexp) ///
+ _b[interact36]*ln(meduc)

* Depend
nlcom _b[lndepend] + 2*_b[lndepend_sq]*ln(mdepend) ///
+ _b[interact14]*ln(mop) + _b[interact24]*ln(mtitled) ///
+ _b[interact34]*ln(mlabor) + _b[interact45]*ln(mexp) ///
+ _b[interact46]*ln(meduc)

* Experience
nlcom _b[lnexp] + 2*_b[lnexp_sq]*ln(mexp) ///
+ _b[interact15]*ln(mop) + _b[interact25]*ln(mtitled) ///
+ _b[interact35]*ln(mlabor) + _b[interact45]*ln(mdepend) ///
+ _b[interact56]*ln(meduc)

* Education
nlcom _b[lneduc] + 2*_b[lneduc_sq]*ln(meduc) ///
+ _b[interact16]*ln(mop) + _b[interact26]*ln(mtitled) ///
+ _b[interact36]*ln(mlabor) + _b[interact46]*ln(mdepend) ///
+ _b[interact56]*ln(mexp)

* Test of uni-modality
* Note: Here we test the hypothesis that the predicted growth rate
* of farms operating less than 5.5 hectares is less than zero. We
* do this by testing whether the predicted value of a representative
* farm is less than zero.
sum operated if operated<5.5
scalar nmop = r(mean)
sum titled if operated<5.5
scalar nmtitled = r(mean)
sum labor if operated<5.5
scalar nmlabor = r(mean)
sum depend if operated<5.5
scalar nmdepend = r(mean)
sum experience if operated<5.5
scalar nmexp = r(mean)
sum education if operated<5.5
scalar nmeduc = r(mean)
sum d1991
scalar nmd1991 = r(mean)
sum d1994 
scalar nmd1994 = r(mean)
sum d1999
scalar nmd1999 = r(mean)
sum dtitled if operated<5.5
scalar nmdtitled = r(mean)
sum dlabor if operated<5.5
scalar nmdlabor = r(mean)
sum ddepend if operated<5.5
scalar nmddepend = r(mean)
sum deduc if operated<5.5
scalar nmdeduc = r(mean)
nlcom _b[_cons] + _b[lnop]*ln(nmop) + _b[lntitled]*ln(nmtitled)  ///   
+ _b[lnlabor]*ln(nmlabor) + _b[lndepend]*ln(nmdepend) ///
+ _b[lnexp]*ln(nmexp) + _b[lneduc]*ln(nmeduc) + _b[lnop_sq]*ln(nmop)^2  /// 
+ _b[interact12]*ln(nmop)*ln(nmtitled) + _b[interact13]*ln(nmop)*ln(nmlabor) ///
+ _b[interact14]*ln(nmop)*ln(nmdepend) + _b[interact15]*ln(nmop)*ln(nmexp) ///
+ _b[interact16]*ln(nmop)*ln(nmeduc) + _b[lntitled_sq]*ln(nmtitled)^2 ///
+ _b[interact23]*ln(nmtitled)*ln(nmlabor) ///
+ _b[interact24]*ln(nmtitled)*ln(nmdepend) ///
+ _b[interact25]*ln(nmtitled)*ln(nmexp) ///
+ _b[interact26]*ln(nmtitled)*ln(nmeduc) + _b[lnlabor_sq]*ln(nmlabor)^2 ///
+ _b[interact34]*ln(nmlabor)*ln(nmdepend) ///
+ _b[interact35]*ln(nmlabor)*ln(nmexp) ///
+ _b[interact36]*ln(nmlabor)*ln(nmeduc) + _b[lndepend_sq]*ln(nmdepend)^2 ///
+ _b[interact45]*ln(nmdepend)*ln(nmexp) ///
+ _b[interact46]*ln(nmdepend)*ln(nmeduc) + _b[lnexp_sq]*ln(nmexp)^2 ///
+ _b[interact56]*ln(nmexp)*ln(nmeduc) + _b[lneduc_sq]*ln(nmeduc)^2 ///
+ _b[d1991]*nmd1991 + _b[d1994]*nmd1994 + _b[d1999]*nmd1999 ///
+ _b[dtitled]*nmdtitled + _b[dlabor]*nmdlabor + _b[ddepend]*nmddepend ///
+ _b[deduc]*nmdeduc

* Divide p-value by 2 for one-sided test
disp 0.117/2

************************************************
******************* Figures ********************
************************************************

* Note: In what follows we develop a bootstrapping 
* procedure to generate confidence intervals for the 
* figures. At present, the confidence intervals are
* not used in the constructed figures. However, we
* have kept the code in case future changes are 
* desired.

* Create data set to store results of bootstrapping
preserve
clear 
set obs 600 
gen operated = _n  /* Covers observed farm size spectrum */
save ./simresults.dta, replace
restore

* Generate land owned variables for experiment
gen sowned = owned
replace sowned = 1 if sowned<1
gen lnowned = ln(sowned)
gen lnowned_sq = lnowned^2
gen downed = 0
replace downed = 1 if owned<1

* Generate stratification variable
* Note: To preserve the unbalanced structure of the panel we stratify by a 
* variable that counts the number of times each household is observed.
* Further, to ensure that a sufficient number of large farms are sampled
* we also stratify by farm size. 
bysort numero (time): egen counts = count(numero)
gen size = .
replace size = 1 if operated <=5
replace size = 2 if operated >5 & operated<=10
replace size = 3 if operated >10 & operated<=20
replace size = 4 if operated >20 & operated<=50
replace size = 5 if operated >50 & operated!=.
gen strata = 10*counts + size

* Set seed
set seed 12345 

* Define forvalues command
forvalues i=0/1000 {    /* 1,000 replications */
    * Preserve current state of data
    preserve
    * Draw sample 
    * Note: Let first iteration run on original data
    if `i'>0 {
        xtset, clear
        bsample, cluster(numero) idcluster(newid) strata(strata)
        * Note: newid is unique within strata, but not across strata.
        * As such, generate newnewid.
        egen newnewid=group(newid strata)
        xtset newnewid time, noquery
    }
    * Run CR regression
    quietly xtabond2 growth $rhs, iv($ivs, eq(level)) ///
    gmm($gmms, collapse lag(1 2)) twostep robust orthog
    * Retrive predicted values for ex ante case
    predict growth_no
    * Retrive predicted values for ex post case
    * Note: Simply use replace command as RHS variables are no longer needed.
    replace lntitled = lnowned
    replace interact12 = lnop*lnowned
    replace lntitled_sq = lnowned_sq
    replace interact23 = lnowned*lnlabor
    replace interact24 = lnowned*lndepend
    replace interact25 = lnowned*lnexp
    replace interact26 = lnowned*lneduc
    replace dtitled = downed
    predict growth_yes  
    * Save intermediate data set
    save ./temp.dta, replace
    * Define foreach loop
    foreach j in growth_no growth_yes {
        * Open intermediate data set
        use ./temp.dta, clear
        * Run fractional polynomial regression
        quietly fracpoly: regress `j' operated
        * Store mean of scaled operated
        gen x = operated/`e(fp_sfac)' if e(sample)
        quietly sum x
        scalar xbar = r(mean)  
        * Open simresults.dta
        * Note: Keep fracpoly estimates in memory
        use ./simresults.dta, clear
        * Retrieve predicted values
        tokenize `e(fp_pwrs)'  /* Stores individual values as macros */
        gen Ioper__1 = (operated/`e(fp_sfac)')^(`1') - xbar^(`1')
        gen Ioper__2 = (operated/`e(fp_sfac)')^(`2') - xbar^(`2')
        predict p`j'`i'
        drop Ioper__1 Ioper__2
        * Save results and restore data
        save ./simresults.dta, replace
    }
    * Erase intermediate data set
    erase ./temp.dta
    * Restore to previous state
    restore
}

* Plot predicted growth and land operated
* Note: Extreme values are trimmed simply to provide a better depiction
* of the data.
use ./simresults.dta, clear
order operated pgrowth_no* pgrowth_yes*
twoway (line pgrowth_no0 operated if operated>3 & operated<600, sort), ///
ytitle(Percentage Growth Rate) xtitle(Land Operated (Ha)) scheme(s2mono)

* Plot results of titling experiment
* Note: Extreme values are trimmed simply to provide a better depiction
* of the data.
twoway (line pgrowth_no0 operated if operated>3 & operated<600, sort) ///
(line pgrowth_yes0 operated if operated>3 & operated<600, sort), ///
ytitle(Percentage Growth Rate) xtitle(Land Operated (Ha)) scheme(s2mono) ///
legend(order(1 "Ex ante" 2 "Ex post")) 




